@@ -1,10 +1,14 @@
+use nxui::Event::*;
 use nxui::NativesAndMessaging::*;
 use nxui::{messagebox, window, windowclass};
 
 fn main() {
-    let msg_box = messagebox::MessageBox::new("Question".to_string(),"Do you want to create a window?".to_string());
+    let msg_box = messagebox::MessageBox::new(
+        "Question".to_string(),
+        "Do you want to create a window?".to_string(),
+    );
     match msg_box.show(BUTTONSTYLE_YESNO, DIALOGSTYLE_QUESTION, DIALOGHINT_MODAL) {
-        6 => {
+        YES => {
             let class = windowclass::WindowClass::new(
                 "window".to_string(),
                 "io.github.lattesyobon.space".to_string(),
@@ -12,7 +16,9 @@ fn main() {
             let window = window::Window::new(class, "Hello World".to_string(), 1280, 750, 500, 500);
             window.show(WINDOWSTYLE_OVERLAPPED);
         }
-        7 => {println!("No window was created.")}
+        NO => {
+            println!("No window was created.")
+        }
         _ => {}
     }
 }
