@@ -1,5 +1,7 @@
 use crate::Event;
 use windows_sys::Win32::UI::WindowsAndMessaging::MESSAGEBOX_STYLE;
+#[cfg(unix)]
+use gtk::*;
 
 #[cfg(windows)]
 pub struct MessageBox {
@@ -7,7 +9,7 @@ pub struct MessageBox {
     pub message: String,
 }
 
-#[cfg(linux)]
+#[cfg(unix)]
 pub struct MessageBox {
     pub title: String,
     pub message: String,
@@ -84,8 +86,8 @@ impl MessageBox {
     }
 }
 
-#[cfg(linux)]
-impl MessaddeBox {
+#[cfg(unix)]
+impl MessageBox {
     ///
     /// Create a new dialog
     ///
@@ -145,7 +147,7 @@ impl MessaddeBox {
             &self.message,
         );
         let event_handler = Event::DialogEventHandler::new();
-        let event = event_handler.set_event_gtk(dialog.run());
+        let event = event_handler.set_event(dialog.run());
         println!("{}", event);
         unsafe {
             dialog.destroy();
