@@ -13,7 +13,7 @@ pub struct Window {
     pub y: i32,
 }
 
-#[cfg(linux)]
+#[cfg(unix)]
 pub struct Window {
     pub class: PSTR,
     pub title: String,
@@ -161,7 +161,7 @@ impl Window {
     }
 }
 
-#[cfg(linux)]
+#[cfg(unix)]
 impl Window {
     ///
     /// Create a new window
