@@ -7,7 +7,7 @@ pub struct WindowClass {
     application_id: String,
 }
 
-#[cfg(linux)]
+#[cfg(unix)]
 #[derive(Clone, Debug)]
 pub struct WindowClass {
     class: String,
@@ -33,7 +33,7 @@ impl WindowClass {
     }
 }
 
-#[cfg(linux)]
+#[cfg(unix)]
 impl WindowClass {
     pub fn new(class: String, application_id: String) -> Self {
         Self {
